# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 2.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_metadata_service_async_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_procedures(self) -> None:
        """Test case for get_procedures

        Get Procedures
        """
        pass

    async def test_get_subject(self) -> None:
        """Test case for get_subject

        Get Subject
        """
        pass

    async def test_get_v1_bergamo_session(self) -> None:
        """Test case for get_v1_bergamo_session

        Get V1 Bergamo Session
        """
        pass

    async def test_get_v1_funding(self) -> None:
        """Test case for get_v1_funding

        Get V1 Funding
        """
        pass

    async def test_get_v1_injection_materials(self) -> None:
        """Test case for get_v1_injection_materials

        Get V1 Injection Materials
        """
        pass

    async def test_get_v1_instrument(self) -> None:
        """Test case for get_v1_instrument

        Get V1 Instrument
        """
        pass

    async def test_get_v1_intended_measurements(self) -> None:
        """Test case for get_v1_intended_measurements

        Get V1 Intended Measurements
        """
        pass

    async def test_get_v1_mgi_allele(self) -> None:
        """Test case for get_v1_mgi_allele

        Get V1 Mgi Allele
        """
        pass

    async def test_get_v1_perfusions(self) -> None:
        """Test case for get_v1_perfusions

        Get V1 Perfusions
        """
        pass

    async def test_get_v1_procedures(self) -> None:
        """Test case for get_v1_procedures

        Get V1 Procedures
        """
        pass

    async def test_get_v1_project_names(self) -> None:
        """Test case for get_v1_project_names

        Get V1 Project Names
        """
        pass

    async def test_get_v1_protocols(self) -> None:
        """Test case for get_v1_protocols

        Get V1 Protocols
        """
        pass

    async def test_get_v1_rig(self) -> None:
        """Test case for get_v1_rig

        Get V1 Rig
        """
        pass

    async def test_get_v1_slims_workflow(self) -> None:
        """Test case for get_v1_slims_workflow

        Get V1 Slims Workflow
        """
        pass

    async def test_get_v1_subject(self) -> None:
        """Test case for get_v1_subject

        Get V1 Subject
        """
        pass

    async def test_index(self) -> None:
        """Test case for index

        Index
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 2.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from aind_metadata_service_async_client.models.http_validation_error import HTTPValidationError
from aind_metadata_service_async_client.models.health_check import HealthCheck
from aind_metadata_service_async_client.models.slims_workflow import SlimsWorkflow
from aind_metadata_service_async_client.models.validation_error import ValidationError
from aind_metadata_service_async_client.models.validation_error_loc_inner import ValidationErrorLocInner
